<h6 align="left">
    <img src="https://cdnquakingaspen.s3.eu-central-1.amazonaws.com/quaking+aspen+logo+teal+full-02.png"  />
</h6>

# sql-database-service
[Introduction](#Introduction)\
[Getting Started](#Started)\
[Contributors](#Contributors)\
[License](#License)
<h2 id="Introduction">Introduction</h2>
This repo provides a library to do the basic CRUD operations in addition to grouping and sorting on an SQL database
 
<h2 id="Started">Getting Started</h2>
In order to install,open the command prompt and type ✌️:

```
pip install sql_database_service
```




<h2 id="">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/Quakingaspen-codehub/sql_database_service/graphs/contributors">
""
</a>

<h2 id="License">License</h2>

This library is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details.
